==> 0.0.3.tar.gz: lib/tendo.dart <==
library tendolib;

import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:tendolib/CreateAccountRequest.dart';
import 'package:tendolib/CreateAccountResponse.dart';
import 'package:tendolib/GetAccountRequest.dart';
import 'package:tendolib/GetAccountResponse.dart';
import 'package:tendolib/GetProductRequest.dart';
import 'package:tendolib/CreateOrderRequest.dart';
import 'package:tendolib/CreateOrderResponse.dart';
import 'package:tendolib/GetOrderRequest.dart';
import 'package:tendolib/GetOrderResponse.dart';
import 'package:tendolib/ShareResponse.dart';
import 'package:tendolib/ShareRequest.dart';
import 'package:tendolib/WishlistRequest.dart';
import 'package:tendolib/WishlistResponse.dart';
import 'package:tendolib/SharelistRequest.dart';
import 'package:tendolib/SharelistResponse.dart';
import 'package:tendolib/GetWishistRequest.dart';
import 'package:tendolib/GetWishistResponse.dart';


class Tendo {

  var baseUrl="http://tendo-api.westeurope.azurecontainer.io";

  Future<CreateAccountResponse> createAccount (CreateAccountRequest accountRequest) async {
    var json = jsonEncode(accountRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/createAccount",
        headers: {"Content-Type": "application/json"},
        body: json);
    return CreateAccountResponse.fromJson(jsonDecode(response.body));
  }

  Future<GetAccountResponse> getAccount(GetAccountRequest accountRequest) async {
    final http.Response response = await http.get( baseUrl+"/getAccount?accountId="+accountRequest.accountId.toString()+"&phoneNumber="+accountRequest.phoneNumber);
    return GetAccountResponse.fromJson(jsonDecode(response.body));
  }


  Future<CreateOrderResponse> createOrder(CreateOrderRequest orderRequest) async{
    var json = jsonEncode(orderRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/createOrder",
        headers: {"Content-Type": "application/json"},
        body: json);
    return CreateOrderResponse.fromJson(jsonDecode(response.body));
  }

  Future<GetOrderResponse> getOrder (GetOrderRequest orderRequest) async{
    final http.Response response = await http.post( baseUrl+"/getOrder?accountId="+orderRequest.accountID.toString()+"&orderId="+orderRequest.orderId.toString());
    return GetOrderResponse.fromJson(jsonDecode(response.body));

  }

  Future<ShareResponse> share (ShareRequest shareRequest) async{
    var json = jsonEncode(shareRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/share",
        headers: {"Content-Type": "application/json"},
        body: json);
    return ShareResponse.fromJson(jsonDecode(response.body));
  }

  Future<WishlistResponse> addToWishlist(WishlistRequest wishlistRequest) async{
    var json = jsonEncode(wishlistRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/addToWishList",
        headers: {"Content-Type": "application/json"},
        body: json);
    return WishlistResponse.fromJson(jsonDecode(response.body));
  }

  Future<GetWishistResponse> getWishlist(GetWishistRequest wishistRequest) async{
    var json = jsonEncode(wishistRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/getWishList",
        headers: {"Content-Type": "application/json"},
        body: json);
    return GetWishistResponse.fromJson(jsonDecode(response.body));
  }

  Future<SharelistResponse> getShareList(SharelistRequest sharelistRequest) async{

    var json = jsonEncode(sharelistRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/shareList",
        headers: {"Content-Type": "application/json"},
        body: json);
    return SharelistResponse.fromJson(jsonDecode(response.body));

  }


}

==> 0.0.6.tar.gz: lib/tendo.dart <==
library tendolib;

import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:tendolib/CreateAccountRequest.dart';
import 'package:tendolib/CreateAccountResponse.dart';
import 'package:tendolib/GetAccountRequest.dart';
import 'package:tendolib/GetAccountResponse.dart';
import 'package:tendolib/CreateOrderRequest.dart';
import 'package:tendolib/CreateOrderResponse.dart';
import 'package:tendolib/GetOrderRequest.dart';
import 'package:tendolib/GetOrderResponse.dart';
import 'package:tendolib/ShareResponse.dart';
import 'package:tendolib/ShareRequest.dart';
import 'package:tendolib/WishlistRequest.dart';
import 'package:tendolib/WishlistResponse.dart';
import 'package:tendolib/SharelistRequest.dart';
import 'package:tendolib/SharelistResponse.dart';
import 'package:tendolib/GetWishistRequest.dart';
import 'package:tendolib/GetWishistResponse.dart';


class Tendo {

  var baseUrl="http://tendo-api.westeurope.azurecontainer.io";

  Future<CreateAccountResponse> createAccount (CreateAccountRequest accountRequest) async {
    var json = jsonEncode(accountRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/createAccount",
        headers: {"Content-Type": "application/json"},
        body: json);
    return CreateAccountResponse.fromJson(jsonDecode(response.body));
  }

  Future<GetAccountResponse> getAccount(GetAccountRequest accountRequest) async {
    final http.Response response = await http.get( baseUrl+"/getAccount?accountId="+accountRequest.accountId.toString()+"&phoneNumber="+accountRequest.phoneNumber);
    return GetAccountResponse.fromJson(jsonDecode(response.body));
  }


  Future<CreateOrderResponse> createOrder(CreateOrderRequest orderRequest) async{
    var json = jsonEncode(orderRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/createOrder",
        headers: {"Content-Type": "application/json"},
        body: json);
    return CreateOrderResponse.fromJson(jsonDecode(response.body));
  }

  Future<GetOrderResponse> getOrder (GetOrderRequest orderRequest) async{
    final http.Response response = await http.get( baseUrl+"/getOrder?accountId="+orderRequest.accountID.toString()+"&orderId="+orderRequest.orderId.toString());
    return GetOrderResponse.fromJson(jsonDecode(response.body));

  }

  Future<ShareResponse> share (ShareRequest shareRequest) async{
    var json = jsonEncode(shareRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/share",
        headers: {"Content-Type": "application/json"},
        body: json);
    return ShareResponse.fromJson(jsonDecode(response.body));
  }

  Future<WishlistResponse> addToWishlist(WishlistRequest wishlistRequest) async{
    var json = jsonEncode(wishlistRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/addToWishList",
        headers: {"Content-Type": "application/json"},
        body: json);
    return WishlistResponse.fromJson(jsonDecode(response.body));
  }

  Future<GetWishistResponse> getWishlist(GetWishistRequest wishistRequest) async{
    var json = jsonEncode(wishistRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/getWishList",
        headers: {"Content-Type": "application/json"},
        body: json);
    return GetWishistResponse.fromJson(jsonDecode(response.body));
  }

  Future<SharelistResponse> getShareList(SharelistRequest sharelistRequest) async{

    var json = jsonEncode(sharelistRequest.toJson());
    final http.Response response = await http.post( baseUrl+"/shareList",
        headers: {"Content-Type": "application/json"},
        body: json);
    return SharelistResponse.fromJson(jsonDecode(response.body));

  }


}
